This feature uses singular value decomposition (SVD) to reduce the dimensionality of the inputted hidden
markov model matrix. SVD factorizes a matrix C of dimensions \(i, j\) to \(U[i, r] \times \Sigma[r, r] \times V[r, j]\).
The diagonal values of \(\Sigma\) are known as the singular values of matrix C, and are what are returned with this function.
Usage
hmm_svd(hmm)
Value
A vector of length 20.
Arguments
hmm
The name of a profile hidden markov model file.
References
Song, X., Chen, Z., Sun, X., You, Z., Li, L., & Zhao, Y. (2018).
An Ensemble Classifier with Random Projection for Predicting Protein–Protein Interactions Using Sequence and Evolutionary Information.
Applied Sciences, 8(1), 89.